﻿using System.Linq;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;
using BusinessObject;


namespace ToolKit
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();

            this.Loaded += new RoutedEventHandler(MainPage_Loaded);

            
        }

        void MainPage_Loaded(object sender, RoutedEventArgs e)
        {
            this.treeView1.ItemsSource = SampleData.SamplePlaceItemCollection;
            this.treeView1.ExpandAll();
            //var obj = this.treeView1.Items[1];
        }

        /// <summary>
        /// 点击节点时，选中子节点，同时设置父节点状态
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ItemCheckbox_Click(object sender, RoutedEventArgs e)
        {
            TreeViewItem item = GetParentTreeViewItem((DependencyObject)sender);
            if (item != null)
            {
                PlaceItem feature = item.DataContext as PlaceItem;
                if (feature != null)
                {
                    UpdateChildrenCheckedState(feature);
                    UpdateParentCheckedState(item);
                }
            }
        }


        /// <summary>
        /// 取得节点的父节点
        /// </summary>
        /// <param name="item"></param>
        /// <returns></returns>
        private static TreeViewItem GetParentTreeViewItem(DependencyObject item)
        {
            if (item != null)
            {
                DependencyObject parent = VisualTreeHelper.GetParent(item);
                TreeViewItem parentTreeViewItem = parent as TreeViewItem;
                return (parentTreeViewItem != null) ? parentTreeViewItem : GetParentTreeViewItem(parent);
            }
            return null;
        }


        /// <summary>
        /// 更新父节点的选中状态
        /// </summary>
        /// <param name="item"></param>
        private static void UpdateParentCheckedState(TreeViewItem item)
        {
            //取得父节点
            TreeViewItem parent = GetParentTreeViewItem(item);
            if (parent != null)
            {
                PlaceItem parentItem = parent.DataContext as PlaceItem;
                if (parentItem != null)
                {                   
                    bool? childrenCheckedState = parentItem.Children.First<PlaceItem>().IsSelected;
                    for (int i = 1; i < parentItem.Children.Count(); i++)
                    {
                        if (childrenCheckedState != parentItem.Children[i].IsSelected)
                        {
                            childrenCheckedState = null;
                            break;
                        }
                    }
                   
                    parentItem.IsSelected = childrenCheckedState;

                    //递归处理上级父节点
                    UpdateParentCheckedState(parent);
                }
            }
        }

        /// <summary>
        /// 更新子节点选中状态
        /// </summary>
        /// <param name="feature"></param>
        private static void UpdateChildrenCheckedState(PlaceItem feature)
        {
            if (feature.IsSelected.HasValue)
            {
                foreach (PlaceItem childFeature in feature.Children)
                {
                    childFeature.IsSelected = feature.IsSelected;
                    if (childFeature.Children.Count() > 0)
                    {
                        UpdateChildrenCheckedState(childFeature);
                    }
                }
            }
        }
    }
}
